/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.console.webui.commons;

import java.util.HashSet;

import org.exoplatform.web.application.Parameter;
import org.exoplatform.webui.core.UIComponent;

/**
 * Nova action is a class that encapsulate an action. It allow to simplify the
 * action event management.
 * 
 * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */
public class NovaAction {

  /**
   * The key header of the nova
   */
  private String header;

  /**
   * The event associated to the nova action
   */
  private String event;

  /**
   * The parameters array for the event of the nova action
   */
  private String[] params;

  /**
   * Confirm message
   */
  private String confirm = null;

  /** Constructors **/

  public NovaAction(String event, String header, String confirmMsg) {
    this.configure(header, event, confirmMsg, null);
  }

  public NovaAction(String event, String header, String[] params, String confirmMsg) {
    this.configure(header, event, confirmMsg, params);
  }

  public NovaAction(String event, String header, String[] params) {
    this.configure(header, event, null, params);
  }

  public NovaAction(String event, String header) {
    this.configure(header, event, null, null);
  }

  /**
   * Get the name of the nova action
   * 
   * @return the name of the nova action
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  public String getName() {
    return event;
  }

  /**
   * Configure a Nova Action
   * 
   * @param the header of the action
   * @param the event asssociated to the action
   * @param the message confirmation
   * @param the parameters of the event
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  private void configure(String header, String event, String confirmMsg, String[] params) {
    this.header = header;
    this.event = event;
    this.params = params;
    this.confirm = confirmMsg;
  }

  /**
   * Generate an event url that send an action event to the given ui component
   * 
   * @param the ui component that receive the event (action)
   * @param the data associated to the event
   * @return the generated url of the event
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  public String link(UIComponent component, NovaData data) throws Exception {
    /* prepare the params */
    if (this.params == null) {
      return component.event(this.event, data.get(this.header));
    }
    HashSet<Parameter> parameters = new HashSet<Parameter>();
    for (int i = 0; i < this.params.length; i++) {
      parameters.add(new Parameter(this.params[i], data.get(this.params[i])));
    }
    return component.event(this.event, data.get(this.header), parameters.toArray(new Parameter[1]));
  }

  public boolean hasConfirm() {
    return null != this.confirm;
  }

  public String getConfirm() {
    return this.confirm == null ? "" : this.confirm;
  }
}
