/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.console.webui.commons;

import java.util.List;

import org.exoplatform.commons.utils.PageList;
import org.exoplatform.webui.config.annotation.ComponentConfig;
import org.exoplatform.webui.config.annotation.EventConfig;
import org.exoplatform.webui.core.UIComponent;
import org.exoplatform.webui.event.Event;
import org.exoplatform.webui.event.EventListener;

/**
 * UINovaPageIterator allow to manage the pagination in User Interface part.
 * 
 * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
 * @author Elwalid BRAHIM <elwalid.brahim@bull.net>
 * 
 * @todo Check if this class is useful
 * @todo Complete the comments
 */
@ComponentConfig(
    template = "system:/groovy/webui/core/UIPageIterator.gtmpl", 
    events = @EventConfig(listeners = UINovaPageIterator.ShowPageActionListener.class))
public class UINovaPageIterator extends UIComponent {

  /**
   * The list of pages
   */
  private PageList pageListItern = PageList.EMPTY_LIST;

  /** Constructor **/
  public UINovaPageIterator() {
  }

  /**
   * Set the list of pages
   * 
   * @param page list
   */
  public void setPageList(PageList pageList) {
    pageListItern = pageList;
  }

  /**
   * Get the pages list of the nova page iterator
   * 
   * @return page list
   */
  public PageList getPageList() {
    return pageListItern;
  }

  /**
   * Get the number of available pages in the nova page iterator
   * 
   * @return int
   */
  public int getAvailablePage() {
    return pageListItern.getAvailablePage();
  }

  /**
   * Get the current page data
   * 
   * @return data list
   * @throws Exception
   */
  @SuppressWarnings("unchecked")
  public List getCurrentPageData() throws Exception {
    return pageListItern.currentPage();
  }

  /**
   * @unused
   */
  public int getCurrentPage() {
    return pageListItern.getCurrentPage();
  }

  /**
   * @unused
   */
  public int getAvailable() {
    return pageListItern.getAvailable();
  }

  /**
   * @unused
   */
  public int getFrom() {
    return pageListItern.getFrom();
  }

  /**
   * @unused
   */
  public int getTo() {
    return pageListItern.getTo();
  }

  /**
   * @unused
   */
  public Object getObjectInPage(int index) throws Exception {
    return pageListItern.currentPage().get(index);
  }

  /**
   * This method set the current page to the given page
   * 
   * @param page
   * @throws exception
   */
  public void setCurrentPage(int page) throws Exception {
    pageListItern.getPage(page);
  }

  /**
   * This subclass is the listener of the show page event. It swith to the page
   * given as parameter of the event.
   * 
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  public static class ShowPageActionListener extends EventListener<UINovaPageIterator> {

    /**
     * The execute method of the listener
     * 
     * @throws Exception
     */
    public void execute(Event<UINovaPageIterator> event) throws Exception {
      try {
        UINovaPageIterator uiPageIterator = event.getSource();
        int page = Integer.parseInt(event.getRequestContext().getRequestParameter(OBJECTID));
        uiPageIterator.setCurrentPage(page);
        UIComponent parent = uiPageIterator.getParent();
        if (parent == null) {
          return;
        }
        event.getRequestContext().addUIComponentToUpdateByAjax(parent);
        //event.getRequestContext().addUIComponentToUpdateByAjax(uiPageIterator)
        // ;
        parent.broadcast(event, event.getExecutionPhase());
      } catch (Exception e) {
        throw e;
      }
    }
  }

}
